---
title: <span class="badge builder"></span> Count
---
# <span class="badge builder"></span> Count

## Constructor

```python
Count()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.Count
```

### <span class="badge object-method"></span> hide

```python
def hide(hide: bool) -> typing.Self
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [Count](./object-Count.md)
